@@ -127,7 +127,7 @@ sub prepare {
 		my $r = $result[$resi];
 		my @l = select_regions({ strict => $self->{strict} },
 				       $r, \@select, $reg->flag);
-		if ($self->{region_index} or @result == 1) {
+		if ($self->{region_index} // @result == 1) {
 		    map { $_->[2] = $regi } @l;
 		}
 		push @{$tmp[$resi]}, @l;
